import objectdraw.*;
import java.awt.*;
import java.util.ArrayList;

/*
 * Example Drag4ShirtsArrayList
 *
 * Drag a shirt around window, given choice of red shirt, blue shirt,
 * green shirt, and yellow shirt, but now stored in an ArrayList.
 *
 * Jim Teresco, Siena College, CSIS 120, Spring 2012
 * Updated for CSC 252, The College of Saint Rose, Spring 2014
 *
 * $Id: Drag4ShirtsArrayList.java 2343 2014-04-06 02:17:18Z terescoj $
 */

public class Drag4ShirtsArrayList extends WindowController {

    // starting location of t-shirt
    private static final int ITEM_LEFT = 75;
    private static final int ITEM_TOP = 50;
    private static final int SND_OFFSET = 150;

    // our list of T-shirts on the screen
    // note also that we have a new "import" at the top for the ArrayList
    private ArrayList<TShirt> shirts;

    // The piece of laundry to be moved.
    private TShirt selectedShirt;

    // Previously noted position of mouse cursor
    private Location lastPoint;

    // Whether user is actually dragging a shirt
    private boolean dragging;

    // display the shirts, store them in an ArrayList
    public void begin() {

        // first, construct our ArrayList that can hold TShirt objects
        shirts = new ArrayList<TShirt>();

        // now, create each shirt and add it to the ArrayList
        TShirt shirt = new TShirt(ITEM_LEFT, ITEM_TOP, canvas);
        shirt.setColor(Color.red);
        shirts.add(shirt);

        shirt = new TShirt(ITEM_LEFT + SND_OFFSET, ITEM_TOP, canvas);
        shirt.setColor(Color.blue);
        shirts.add(shirt);

        shirt = new TShirt(ITEM_LEFT, ITEM_TOP + SND_OFFSET, canvas);
        shirt.setColor(Color.green);
        shirts.add(shirt);

        shirt = new TShirt(ITEM_LEFT + SND_OFFSET, ITEM_TOP + SND_OFFSET, canvas);
        shirt.setColor(Color.yellow);
        shirts.add(shirt);

        selectedShirt = shirt; // last created shirt "on top" at start (it has to
        // be one of them, doesn't really matter which)
    }

    // Whenever the mouse is pressed, note its location
    // and which (if any) shirt the mouse is on.
    public void onMousePress(Location point) {
        lastPoint = point;

        // start out assuming that we are not on top of any shirt, which
        // means we will not be dragging.
        dragging = false;

        // test the selected shirt (which is on top) first.
        if (selectedShirt.contains(point)) {
            dragging = true;
        } else {
            // otherwise, look at each shirt in the ArrayList in turn, see if
            // it contains the point.  If we find one, we set it as the 
            // selected shirt so it will be dragged around and set dragging to true
            for (int shirtNum = 0; shirtNum < shirts.size(); shirtNum++) {
                TShirt shirt = shirts.get(shirtNum);
                if (shirt.contains(point)) {
                    selectedShirt = shirt;
                    dragging = true;
                    selectedShirt.sendToFront();
                }
            }
        }
    }

    // If mouse is dragged, move the selected shirt with it
    // If didn't press mouse on a shirt, do nothing
    public void onMouseDrag(Location point) {
        if (dragging) {
            selectedShirt.move(point.getX() - lastPoint.getX(),
                point.getY() - lastPoint.getY());
            lastPoint = point;
        }
    }

    // move all shirts back to starting positions when mouse leaves window
    public void onMouseExit(Location point) {

        for (int shirtNum = 0; shirtNum < shirts.size(); shirtNum++) {
            shirts.get(shirtNum).reset();
        }
        dragging = false;
    }
}
